c*********************************************************************
c $Source: /long/munnich/CVSROOT/UCLA/QTCM/src/clrad0.F,v $
c $Author: munnich $
c $Revision: 1.3 $
c $Date: 2000/08/11 22:47:39 $
c
c File:  clrad0.f
c
c This contains a simple cloud and radiation package. Retaining much
c   accuracy, its "analytical" ability makes it easy to understand what's
c   going on.
c
c 1. cloud:     Interactive (High+Mid) clouds depend on precipitation through
c               empirical relationship; low+Nimbo clouds fixed to a reference
c               value; radiation are treated correspondingly
c
c 2. solartop:  Diurnally averaged ; easy modification for orbital
c               parameters
c
c 3. Shortwave: Single cloud-atmosphere layer, two-stream, analytical
c
c 4. Longwave:  Linear longwave radiation scheme
c
c Code history:
c   Original version (QTCM1 V1a):  Zeng/Chou/Neelin  Jan 1997
c   Beta version (QTCM1 V1b):                        Jun 1997
c   QTCM1 release (QTCM1 V2.0):                      Jun 1998
c   QTCM1 V2.1: new b1 profile/reclassification
c     of interactive/noninteractive cloud types      Dec 1998
c*********************************************************************

             subroutine cloud
c************
c cloud prediction; deep convective cloud cover proportional to convective
c   precipitation 
c 
c We lump clouds into two categories: interactive and noninteractive, with
c the former proportional to rainfall (predicted by QTCM), the latter
c fixed at its tropical mean.
c In the following, we lump high clouds (types 5,6,7 of ISCCP) and AsAc (3) as
c  a single interactive type (called High+Middle), while 1,2,4 are lumped
c  as one noninteractive cloud type (loosely called low clouds);
c  the reason we put Nimbostratus as noninteractive is because it has
c  little correlation with rainfall.

      implicit none
      include 'hgrid.h'
      include 'qtcm.h'
      include 'pmean.h'

c --Altered Common Variables:
c cl3          !cloud cover          fraction
 
c --Local Variables & Functions:
      integer i,j
      REAL cl3P,cl1ref,cl3ref
c@
      common/clcom/ cl1ref,cl3ref
      
      data cl3P/0.0018/      !convert Prec. into cloud cover; 100% / W/M^2
      data cl1ref/0.36/      !reference state low cloud; for convective region
      data cl3ref/0.21/      !reference state high+middle cloud cover   100%

c*****************************************************************

      do j=1,NY
      do i=1,NX
         cl3(i,j)=cl3P*Qc(i,j)          !proportional to deep convective prec.
         cl3(i,j)=min(cl3(i,j),one)   !cloud cover not allowed to exceed 100%
c        cl3(i,j)=cl3ref                !@ mean cloud
      end do
      end do

      return
      end


             subroutine solartop
c************
c Solar radiation at TOA, diurnally averaged
c
c Astronomical formulae used:
c 1.  solar declination angle as a function of dayofyear     Zeng(1994)
c     derived by assuming a circular orbit (tiny error)
c 2.  correction(<3.4%) to solar constant due to the 
c     ellipticity of the earth orbit, function of dayofyear  Dickinson(1983)
c 3.  Diurnally averaged solar zenith angle                  Sellers(1965),Zeng
c
c Length of year =DAYSPERYEAR to accomodate qtcm coupling
c
      implicit none
      include 'hgrid.h'
      include 'qtcm.h'
#include "calendar.h"
 
c --Altered Common Variables:
c S0
 
c --Local Variables & Functions:
      REAL sint,cost,dtheta
      REAL cosZbar
      REAL cosHor,sinHor,Hor
      REAL sint0,cost0,theta0,theta0max
      REAL SolarC
      REAL dayspring,dayperihelion,ecce
      integer i,j
c*****************************************************************
 
c- orbital parameters
      theta0max=23.447                 !degree; max solar dec. angle
      dayspring = 81.                  !Julian day of Vernal Equinox
      dayperihelion = 3.               !day of year closest to the sun
      ecce = 0.034                     !related to eccentricity of earth orbit

      sint0  = sin(theta0max/180.*pi) *                 !Zeng (1994)
     &         sin(2.*pi*(dayofyear-dayspring)/DAYSPERYEAR.)   
      theta0 = asin(sint0)                    !solar declination angle
      cost0  = cos(theta0)
      SolarC = 1370.*(1.+ecce*
     &                cos(2.*pi*(dayofyear-dayperihelion)/DAYSPERYEAR.))
      dtheta=dy/Rearth

      do j=1,NY
          sint=sin((j-(NY+1)*half)*dtheta)               ! sint=sin(lat)
          cost=sqrt(one-sint**2)
          cosHor=-sint*sint0/(cost*cost0)
c winter and summer polar regions; not needed for a tropical model
          cosHor=max(cosHor,-one)       !polar; no night; halfday length=pi
          cosHor=min(cosHor,one)        !polar; no day; halfday length=0
          Hor=acos(cosHor)
          sinHor=sqrt(one-cosHor**2)
          cosZbar=(sint*sint0*Hor+cost*cost0*sinHor)/pi   !Sellers(1966)
          S0(1,j)=SolarC*cosZbar
          do i=2,NX                             !no dependence on i
              S0(i,j)=S0(1,j)
          end do
      end do

      return
      end


             subroutine radsw
c************
c A rudimentary shortwave radiation scheme; Zeng/Neelin (J.Climate 1998)
c Analytically solved surface and top fluxes for a single layer of 
c   cloud-atmo with reflectivity 'albdc' (including cloud
c   albedo and atmospheric backscattering) and absorptivity 'absp', over a 
c   surface with albedo 'ALBDs'. The cloud albedo dependence on cloud cover
c   is computed with solar zenith angle effects absorbed in.
c 
      implicit none
      include 'hgrid.h'
      include 'qtcm.h'
      include 'pmean.h'

c --Altered Common Variables:
c FSWs         !net (absorbed by ground) surface solar         W/m**2
c FSW          !total SW absorbed by column   W/m**2
 
c --Local Variables & Functions:
      integer i,j
      REAL absp0,abspc1,abspc3,absp,albdc,albdc0,albdc1,albdc3
      REAL ALBDst,frac
      REAL cl1ref,cl3ref
      common/clcom/ cl1ref,cl3ref       !@can we use total cloud for LW ?
c
      data absp0/0.19/     !atmo. absorptivity;   dimensionless
      data abspc1/0.00/    !low cloud absorptivity;   dimensionless
      data abspc3/0.08/    !H+M cloud absorptivity; <- 4% absorption at cl=.5
      data albdc0/0.00/    !clear sky back scattering
      data albdc1/0.30/    !converting low cloud cover into albedo  1/100%
      data albdc3/0.40/    !converting H+M cloud cover into albedo  1/100%
      data frac/0.5/       !fraction absorbed before reflection occurs at top
c*****************************************************************

      call solartop        !get incoming solar at TOA

      do j=1,NY
      do i=1,NX

          albdc=albdc0+albdc1*cl1ref+albdc3*cl3(i,j)     !cloud/atmo albedo

          absp=absp0+abspc1*cl1ref+abspc3*cl3(i,j)       !total absorptivity

          ALBDst=ALBDs(i,j)

          FSWds(i,j)=S0(i,j)*(one-albdc)*(one-absp)      !downward surface
          FSWus(i,j)=FSWds(i,j)*ALBDst                   !upward surface
          FSWut(i,j)=S0(i,j)*( (one-frac*absp)*albdc     !upward top
     1          +((one-albdc)*(one-absp))**2*ALBDst )

          FSW(i,j)=S0(i,j)+FSWus(i,j)-FSWds(i,j)-FSWut(i,j)

      end do
      end do

      return
      end



             subroutine radlw
c************
c Longwave radiation; linear scheme (LINRAD) of Chou and Neelin (1996)
c linearization coefficients calculated by NZ using a tropical mean profile
c 
      implicit none
      include 'hgrid.h'
      include 'qtcm.h'
      include 'pmean.h'

c --Altered Common Variables:
c FLWds         !downward longwave flux at surface         W/m**2
c FLWus         !upward longwave flux at surface           W/m**2
c FLWut         !upward longwave flux at top, i.e., OLR    W/m**2
c FLW           !FLW=FLWus-FLWds-FLWut; total LW absorbed by column   W/m**2
 
c --Local Variables & Functions:
      integer i,j
      REAL FLWdsref,FLWusref,FLWutref
     1  ,eps_rT1t,eps_rT1s,eps_rq1t,eps_rq1s,eps_rclt,eps_rcls
     2  ,eps_rTst,eps_rTss

c
      REAL cl1ref,cl3ref
      common/clcom/ cl1ref,cl3ref       !@can we use total cloud for LW ?

c Values derived from CC(a1,b1 to 200mb, Chia's weakly nonlinear coefficients
c   are used by weighted averaging high+middle clouds); see qtcm/par/rad/coef.sh
      data FLWdsref/431./       !reference state, LW downward surface
      data FLWusref/475./       !reference state, upward surface
      data FLWutref/253./       !reference state, upward top  (OLR)
      data eps_rT1t/1.23/       !top upward IR due to T1, W/m**2/K  -> -42 day
      data eps_rT1s/1.29/       !surface downward IR due to T1, W/m**2/K
      data eps_rq1t/-0.41/      !top upward IR due to q1(in Kelvin) ->75 day
      data eps_rq1s/1.23/       !surface downward IR due to q1(in Kelvin)
      data eps_rclt/-81.1/      !top upward IR due to cloud,W/m2/100%
      data eps_rcls/15.9/       !surface downward IR due to cloud,W/m2/100%
      data eps_rTst/0.533/      !top upward due to Ts    W/m^2/K
      data eps_rTss/6.283/      !surface upward due to Ts W/m^2/K -> 17 day 
      save FLWdsref,FLWusref,FLWutref
     1  ,eps_rT1t,eps_rT1s,eps_rq1t,eps_rq1s,eps_rclt,eps_rcls
     2  ,eps_rTst,eps_rTss
c*****************************************************************

      do j=1,NY
      do i=1,NX

          FLWds(i,j)=FLWdsref+eps_rT1s*T1(i,j)+eps_rq1s*q1(i,j)
     1                 +eps_rcls*(cl3(i,j)-cl3ref)
          FLWus(i,j)=FLWusref+eps_rTss*(Ts(i,j)-Tsref)
          FLWut(i,j)=FLWutref+eps_rT1t*T1(i,j)+eps_rq1t*q1(i,j)
     1                 +eps_rclt*(cl3(i,j)-cl3ref)
     2                 +eps_rTst*(Ts(i,j)-Tsref)

          FLW(i,j)=FLWus(i,j)-FLWds(i,j)-FLWut(i,j)

      end do
      end do

      return
      end
