c
c File  clrad0.f
c
c This contains the cloud and radiation package of Chou and Neelin (Chou, Ph.D
c   Dissertation, UCLA 1997)
c
c Code history:
c   version 2.0 (QTCM1):  Chou/Neelin  June 1997
c
c**************************************************************************
             subroutine cloud
c************
c cloud prediction scheme
c
      implicit none
      include 'hgrid.h'
      include 'qtcm.h'
      include 'cld.h'


      integer itdriver,it
      common/modelday/itdriver,it

c --Input Variables:
c   Qc, cldref

c --output Variables:
c   cldref: reference (mean) cloud cover
c   cld: cloud cover
c                   type 0: clear sky
c                   type 1: Deep cloud +CsCc
c                   type 2: Cirrus
c                   type 3: Stratus
c                   type 4: AsAc+CuSc (constant in space and time)
c   Note: Cloud cover of cloud type 4 has been absorbed into the coefficients
c         for both longwave and solar radiation schemes.

c --Local Variables & Functions:
      integer i,j,n
      REAL cl3P     !coefficients for cloud prediction scheme
      data cl3P/7.76275869D-4/
      data (cldref(n),n=1,clt)/
     1      0.1051000,      0.1047000,     0.1096000,     0.2234000/

c*****************************************************************

c     read ISCCP observed cloudiness
c      call readobscloud('cld','../bnddata/CLOUD_ISCCP')
      do j=1,NY
      do i=1,NX
        cld(i,j,1)=cl3P*Qc(i,j)  !proportional to deep convective precipitation
        cld(i,j,2)=cldref(2)
        cld(i,j,3)=cldref(3)
        cld(i,j,0)=1.-cld(i,j,1)-cld(i,j,2)-cld(i,j,3)-cldref(4)
        cl3(i,j)=cld(i,j,1)
      end do
      end do

      return
      end

c
c*********************************************************************
c
c Read CLOUD COVER data files from ISCCP C2 (monthly)
c

      subroutine readobscloud(var, vardir)
c************
c Time evolving boundary conditions other than SST:
c   prescribed fields such as observed soil moisture, surface
c   radiative fluxes, cloud cover, etc.
c It can be called from the ocean-atmo coupling or land-atmo coupling
c   loops depending on the input data's time resolution, or other
c   coupling intervals if desired.
c*********************************

      implicit none
      include 'hgrid.h'
#include "calendar.h"
      include 'cld.h'

      REAL vardummy(NX,NY,3)
      character*(3) var
      character*(*) vardir

c- Altered
c    vardummy

c- Local Variables and Functions
      integer lnblnk, month_prior, n, i, j
      character*(2) monthc
      character*(12) varfile

      data month_prior/0/
      save month_prior

      if(monthofyear.eq.month_prior) return

      write(monthc,'(i2.2)') monthofyear              !convert into a string
      varfile='0000'//monthc//'15'//'.'//var    !file format: 0000mm15.var

c read the var
      open(13,file=vardir(1:lnblnk(vardir))//'/'//varfile
     &       ,form='formatted',status='old')
      do n=1,3
      do j=1,NY
      do i=1,NX
      read(13,*) vardummy(i,j,n)
      end do
      end do
      end do
      close(13)
      do n=1,3
      do j=1,ny
      do i=1,nx
         cld(i,j,n)=vardummy(i,j,n)
      enddo
      enddo
      enddo

      write (*,*) 'bndry: Read ',var,' at model date', dateofmodel,
     &' from file',vardir(1:lnblnk(vardir))//'/'//varfile

      month_prior=monthofyear

      return
      end


             subroutine radsw
c************
c a simplified solar radiation scheme derived from Fu-Liou scheme (1993).
c             FSW=S0*Ca(1)(1+bs(1))
c             FSWds=S0*Ca(2)(1+bs(2))
c      where
c             Ca(i=1,2)=a(i=1,2)*cosZ+b(i=1,2
c             bs(i=1,2)=c(i=1,2)*ALBDs
c
c     cosZ    : cosine solar zenith angle
c     FSWds   : downward solar radiation at the surface
c     FSWus   : solar reflection at the surface
c     FSWut   : upward solar radiation at the top of the atmosphere
c     SolarC  : solar constant
c     S0      : S0 = SolarC * cosZ
c     ALBDs   : surface albedo
c     Ca(1)   : atmoshperic column absorption including clouds
c     Ca(2)   : ratio of surface solar irradiance and S0
c     bs(1)   : first order contribution due to surface reflection
c     bs(2)   : first order contribution due to surface reflection
c     Note    : Ca and Bs for the cloud type 4 has absorbed the constant 
c               cloud cover, so no cld is in front of Ca when calculating
c               fluxes.
c
c************
c Solar radiation at TOA (S0), without diurnal cycle
c Astronomical formulae used:
c 1.  solar declination angle as a function of dayofyear
c 2.  correction(<3.4%) to solar constant due to the
c     ellipticity of the earth orbit, function of dayofyear  Dickinson(1983)
c
c --Local Variables & Functions:
c    SolarC : solar constant
c    cosZ   :  zenith angle in cosine, cosZ=0 at night
c    cosZ1  : day average of cosZ
c    cosZ2  : day average of cosZ**2
c    lamda  : latitude
c    delta  : solar inclination
c    H      : hour angle at sunset and sunrise
c
c --Altered Common Variables:
c FSW          !total SW absorbed by column   W/m**2
c
      implicit none
      include 'hgrid.h'
      include 'qtcm.h'
#include "calendar.h"
      include 'cld.h'
c
      integer i,j,k
      REAL cosZ1,cosZ2,SolarC
      REAL lamda,sinlamda,sindelta,coslamda
     2,      cosdelta,sinH,sin2H,cosH
     3,      dtheta,delta,H
      REAL dayspring,dayperigee,ecce,theta0max
      REAL Ca(0:clt,2),bs(0:clt,2),a(0:clt,2),b(0:clt,2),c(0:clt,2)
c
c     The coefficients are calculated from Fu-Liou (1993) scheme with
c     a prescribed ocean aerosol distribution.
c
      data (a(i,1),i=0,clt)/
     *              -0.7223246E-01,  0.2799591E-01, -0.3339809E-01,
     *              -0.3023985E-01, -0.1160895E-01/
      data (b(i,1),i=0,clt)/
     *               0.2511668E+00,  0.1754154E+00,  0.2181604E+00,
     *               0.2592998E+00,  0.5483947E-01/
      data (a(i,2),i=0,clt)/
     *               0.1867914E+00,  0.1466297E+00,  0.3125241E+00,
     *               0.2819818E+00,  0.8470821E-01/
      data (b(i,2),i=0,clt)/
     *               0.5848899E+00,  0.8151810E-01,  0.3584682E+00,
     *               0.1479864E+00,  0.6548831E-01/
      data (c(i,1),i=0,clt)/
     *               0.1662990E+00,  0.6342480E-01,  0.1743452E+00,
     *               0.6971303E-01,  0.1354119E+00/
      data (c(i,2),i=0,clt)/
     *               0.1160096E+00,  0.7485682E+00,  0.2741102E+00,
     *               0.5867761E+00,  0.3009433E+00/
c*****************************************************************

     
c- orbital parameters
      theta0max=23.447                 !degree; max solar dec. angle
      dayspring = 81.                  !Julian day of Vernal Equinox
      dayperigee = 3.                  !day of year closest to the sun
      ecce = 0.034                     !related to eccentricity of earth orbit

      sindelta=sin(theta0max/180.*pi) *                 !Zeng (1994)
     &       sin(2.*pi*(dayofyear-dayspring)/DAYSPERYEAR.)    
      delta=asin(sindelta)
      cosdelta=cos(delta)
      SolarC =1370.*(one+ecce*                 ! Dickinson(1983)
     &              cos(2.*pi*(dayofyear-dayperigee)/DAYSPERYEAR.))
      dtheta=dy/Rearth
      do j=1,NY
        lamda=(j-(NY+1)/2)*dtheta
        sinlamda=sin(lamda)
        coslamda=sqrt(one-sinlamda**2)
        cosH=-sinlamda*sindelta/(coslamda*cosdelta)
        cosH=max(cosH,-one)       !polar; no night; halfday length=pi
        cosH=min(cosH,one)        !polar; no day; halfday length=0
        H=acos(cosH)             
        sinH=sqrt(one-cosH**2)
        sin2H=2*sinH*cosH
        cosZ1=(sinlamda*sindelta*H
     2             +coslamda*cosdelta*sinH)/pi
        cosZ2=((sinlamda*sindelta)**2*H
     2           +2*sinlamda*coslamda*sindelta*cosdelta*sinH
     3           +(coslamda*cosdelta)**2*(H/2.-sin2H/4.))/pi
        do k=0,clt
           Ca(k,1)=a(k,1)*cosZ2+b(k,1)*cosZ1
           Ca(k,2)=a(k,2)*cosZ2+b(k,2)*cosZ1
        enddo
      do i=1,NX
c******************************* empirical formula from Fu-Liou scheme
        do k=0,clt
           bs(k,1)=c(k,1)*ALBDs(i,j)
           bs(k,2)=c(k,2)*ALBDs(i,j)
        enddo
cc
        FSW(i,j)=Ca(4,1)*(1.+bs(4,1))
        FSWds(i,j)=Ca(4,2)*(1.+bs(4,2))
        do k=0,cltm1
           FSW(i,j)=FSW(i,j)+cld(i,j,k)*Ca(k,1)*(1.+bs(k,1))
           FSWds(i,j)=FSWds(i,j)+cld(i,j,k)*Ca(k,2)*(1.+bs(k,2))
        enddo
        S0(i,j)=SolarC*cosZ1
        FSW(i,j)=SolarC*FSW(i,j)                    !atmospheric absorption
        FSWds(i,j)=SolarC*FSWds(i,j)                ! surface solar irradiance
        FSWus(i,j)=FSWds(i,j)*ALBDs(i,j)
        FSWut(i,j)=S0(i,j)-FSWds(i,j)-FSW(i,j)+FSWus(i,j)
      end do
      end do

      return
      end


            subroutine radlw
***
c Longwave radiation; weakly nonlinear scheme (LINRAD) of Chou and Neelin (1996)
c linearization coefficients calculated by Chou using a tropical mean profile
c
      implicit none
      include 'hgrid.h'
      include 'qtcm.h'
      include 'cld.h'


c --Altered Common Variables:
c FLWds         !downward longwave flux at surface         W/m**2
c FLWus         !upward longwave flux at surface           W/m**2
c FLWut         !upward longwave flux at top, i.e., OLR    W/m**2
c FLW           !FLW=FLWus-FLWds-FLWut; total LW absorbed by column   W/m**2

c --Local Variables & Functions:
c eps_rxxt    coeficients for calculating total column LW contributed
c        by   x = T     temperature variation
c               = q     moisture variation
c               = c     cloudiness variation
c               = co2   carbon dioxide
c             x = s     surface temperature variation
c        at   x = t     top of the atmosphere
c               = s     the surface
c eps_rxx     coeficients for calculating column LW of each cloud type
c
c Note:c Coefficients for the cloud type 4 has absorbed the constant
c               cloud cover, so no cld is in the calculation of fluxes.

      integer i,j,n
      REAL eps_rTst,eps_rqst,eps_rTtt               !LW radiation,coeff.
     1,      eps_rqtt,eps_rstt
     2,      eps_rcs(clt),eps_rct(clt)
     3,      eps_rTt(0:clt),eps_rqt(0:clt)
     4,      eps_rst(0:clt),eps_rTs(0:clt)
     5,      eps_rqs(0:clt),eps_rss
     6,      eps_rco2s(0:clt),eps_rco2t(0:clt),eps_rco2st,eps_rco2tt
     7,      FLWdsref,FLWusref,FLWutref
     8,      co2m

c*****************************************************************
      data (eps_rct(n),n=1,clt) /
     *     -0.100751E+03, -0.616890E+02, -0.122923E+02,  -0.617279E+01/
      data (eps_rcs(n),n=1,clt) /
     *      0.230918E+02,  0.843160E+01,  0.325455E+02,   0.459770E+01/
      data (eps_rTt(n),n=0,clt) /
     *      0.133549E+01,  0.152938E+01,  0.145419E+01,  0.141225E+01,
     *      0.314753E+00/
      data (eps_rqt(n),n=0,clt) /
     *     -0.806434E+00, -0.644083E-01, -0.352098E+00, -0.471530E+00,
     *     -0.941187E-01/
      data (eps_rst(n),n=0,clt) /
     *      0.535400E+00,  0.109650E-02,  0.208200E+00,  0.900000E-03,
     *      0.257267E-01/
      data (eps_rTs(n),n=0,clt) /
     *      0.129186E+01,  0.174937E+01,  0.151779E+01,  0.183933E+01,
     *      0.376499E+00/
      data (eps_rqs(n),n=0,clt) /
     *      0.259074E+01,  0.656097E+00,  0.173063E+01,  0.118402E+00,
     *      0.192666E+00/
      data eps_rss   /
     *      0.628300E+01/
      data (eps_rco2t(n),n=0,clt) /
     *     -0.564960E+01, -0.326653E+01, -0.419050E+01, -0.559220E+01,
     *     -0.116735E+01/
      data (eps_rco2s(n),n=0,clt) /
     *      0.188300E+00,  0.131395E+00,  0.165100E+00,  0.112100E+00,
     *      0.312150E-01/
      data FLWdsref /443.4288/,    FLWusref /475.3227/,
     2     FLWutref /240.3406/
      data co2m /330.00/
c*****************************************************************

      do j=1,NY
      do i=1,NX
         co2(i,j)=330.
         eps_rTst=eps_rTs(4)  
         eps_rqst=eps_rqs(4)
         eps_rTtt=eps_rTt(4)
         eps_rqtt=eps_rqt(4)
         eps_rstt=eps_rst(4)
         eps_rco2st=eps_rco2s(4)
         eps_rco2tt=eps_rco2t(4)
         do n=0,cltm1                              !calculating eps_rxxt
            eps_rTst=eps_rTst+eps_rTs(n)*cld(i,j,n)  
            eps_rqst=eps_rqst+eps_rqs(n)*cld(i,j,n)
            eps_rTtt=eps_rTtt+eps_rTt(n)*cld(i,j,n)
            eps_rqtt=eps_rqtt+eps_rqt(n)*cld(i,j,n)
            eps_rstt=eps_rstt+eps_rst(n)*cld(i,j,n)
            eps_rco2tt=eps_rco2tt+eps_rco2t(n)*cld(i,j,n)
            eps_rco2st=eps_rco2st+eps_rco2s(n)*cld(i,j,n)
         enddo
c*********   LW contributed by T, q, Ts and cloudiness
         FLWds(i,j)=FLWdsref+eps_rTst*T1(i,j)+eps_rqst*q1(i,j)
     *              +eps_rco2st*(co2(i,j)-co2m)/330.
         FLWut(i,j)=FLWutref+eps_rTtt*T1(i,j)+eps_rqtt*q1(i,j)
     *              +eps_rstt*(Ts(i,j)-Tsref)
     *              +eps_rco2tt*(co2(i,j)-co2m)/330.
         do n=1,cltm1                         !LW contributed by cloudiness
            FLWds(i,j)=FLWds(i,j)+eps_rcs(n)*(cld(i,j,n)-cldref(n))
            FLWut(i,j)=FLWut(i,j)+eps_rct(n)*(cld(i,j,n)-cldref(n))
         enddo
         FLWus(i,j)=FLWusref+eps_rss*(Ts(i,j)-Tsref)        !LW contributed Ts
         FLW(i,j)=FLWus(i,j)-FLWds(i,j)-FLWut(i,j)          !sum of total LW
      end do
      end do

      return
      end
